@@ -1,19 +1,21 @@
-"""Module containing index utilities"""
+# This module is part of GitPython and is released under the
+# 3-Clause BSD License: https://opensource.org/license/bsd-3-clause/
+
+"""Index utilities."""
+
+import contextlib
 from functools import wraps
 import os
+import os.path as osp
 import struct
 import tempfile
-
-from git.compat import is_win
-
-import os.path as osp
-
+from types import TracebackType
 
 # typing ----------------------------------------------------------------------
 
-from typing import Any, Callable, TYPE_CHECKING
+from typing import Any, Callable, TYPE_CHECKING, Optional, Type
 
-from git.types import PathLike, _T
+from git.types import Literal, PathLike, _T
 
 if TYPE_CHECKING:
     from git.index import IndexFile
@@ -31,8 +33,7 @@ unpack = struct.unpack
 # } END aliases
 
 
-class TemporaryFileSwap(object):
-
+class TemporaryFileSwap:
     """Utility class moving a file to a temporary location within the same directory
     and moving it back on to where on object deletion."""
 
@@ -40,19 +41,24 @@ class TemporaryFileSwap(object):
 
     def __init__(self, file_path: PathLike) -> None:
         self.file_path = file_path
-        self.tmp_file_path = str(self.file_path) + tempfile.mktemp("", "", "")
-        # it may be that the source does not exist
-        try:
-            os.rename(self.file_path, self.tmp_file_path)
-        except OSError:
-            pass
+        dirname, basename = osp.split(file_path)
+        fd, self.tmp_file_path = tempfile.mkstemp(prefix=basename, dir=dirname)
+        os.close(fd)
+        with contextlib.suppress(OSError):  # It may be that the source does not exist.
+            os.replace(self.file_path, self.tmp_file_path)
 
-    def __del__(self) -> None:
+    def __enter__(self) -> "TemporaryFileSwap":
+        return self
+
+    def __exit__(
+        self,
+        exc_type: Optional[Type[BaseException]],
+        exc_val: Optional[BaseException],
+        exc_tb: Optional[TracebackType],
+    ) -> Literal[False]:
         if osp.isfile(self.tmp_file_path):
-            if is_win and osp.exists(self.file_path):
-                os.remove(self.file_path)
-            os.rename(self.tmp_file_path, self.file_path)
-        # END temp file exists
+            os.replace(self.tmp_file_path, self.file_path)
+        return False
 
 
 # { Decorators
@@ -80,9 +86,11 @@ def post_clear_cache(func: Callable[..., _T]) -> Callable[..., _T]:
 
 
 def default_index(func: Callable[..., _T]) -> Callable[..., _T]:
-    """Decorator assuring the wrapped method may only run if we are the default
-    repository index. This is as we rely on git commands that operate
-    on that index only."""
+    """Decorator ensuring the wrapped method may only run if we are the default
+    repository index.
+
+    This is as we rely on git commands that operate on that index only.
+    """
 
     @wraps(func)
     def check_default_index(self: "IndexFile", *args: Any, **kwargs: Any) -> _T:
@@ -99,7 +107,7 @@ def default_index(func: Callable[..., _T]) -> Callable[..., _T]:
 
 def git_working_dir(func: Callable[..., _T]) -> Callable[..., _T]:
     """Decorator which changes the current working dir to the one of the git
-    repository in order to assure relative paths are handled correctly"""
+    repository in order to ensure relative paths are handled correctly."""
 
     @wraps(func)
     def set_git_working_dir(self: "IndexFile", *args: Any, **kwargs: Any) -> _T:
